[Libreoffice-commits] core.git: svx/source

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Sat Aug 3 07:49:04 UTC 2019


 svx/source/accessibility/ChildrenManagerImpl.hxx  |    8 ++++----
 svx/source/accessibility/SvxShapeTypes.cxx        |    4 ++--
 svx/source/customshapes/EnhancedCustomShape2d.cxx |    4 ++--
 svx/source/customshapes/EnhancedCustomShape3d.cxx |    2 +-
 svx/source/dialog/connctrl.cxx                    |    2 +-
 svx/source/dialog/docrecovery.cxx                 |    2 +-
 svx/source/dialog/svxruler.cxx                    |    2 +-
 svx/source/engine3d/helperhittest3d.cxx           |    4 ++--
 svx/source/engine3d/helperminimaldepth3d.cxx      |    4 ++--
 svx/source/engine3d/view3d.cxx                    |    4 ++--
 svx/source/fmcomp/fmgridcl.cxx                    |    2 +-
 svx/source/fmcomp/fmgridif.cxx                    |    8 ++++----
 svx/source/fmcomp/gridctrl.cxx                    |   14 +++++++-------
 svx/source/form/filtnav.cxx                       |    2 +-
 svx/source/form/fmscriptingenv.cxx                |    2 +-
 svx/source/form/fmshell.cxx                       |    2 +-
 svx/source/form/fmshimp.cxx                       |    4 ++--
 17 files changed, 35 insertions(+), 35 deletions(-)

New commits:
commit f7613d2132e8115b7741e9397b111508f24615cc
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Fri Aug 2 11:47:52 2019 +0200
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Sat Aug 3 09:47:55 2019 +0200

    Fix typos
    
    Change-Id: Iaf2691b60796300f6c3acf56f60dcc526685eeb9
    Reviewed-on: https://gerrit.libreoffice.org/76855
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>
    Tested-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/svx/source/accessibility/SvxShapeTypes.cxx b/svx/source/accessibility/SvxShapeTypes.cxx
index 142a9d36b60c..5ca2804b5d7f 100644
--- a/svx/source/accessibility/SvxShapeTypes.cxx
+++ b/svx/source/accessibility/SvxShapeTypes.cxx
@@ -57,10 +57,10 @@ static AccessibleShape* CreateSvxAccessibleShape (
         case DRAWING_POLY_LINE_PATH:
         case DRAWING_RECTANGLE:
         case DRAWING_TEXT:
-        // Default accessiblility shape for
+        // Default accessibility shape for
         // css::drawing::CustomShape (#i37790#)
         case DRAWING_CUSTOM:
-        // Default accessiblility shape for
+        // Default accessibility shape for
         // css::drawing::MediaShape (#i85429#)
         case DRAWING_MEDIA:
             return new AccessibleShape (rShapeInfo, rShapeTreeInfo);
diff --git a/svx/source/customshapes/EnhancedCustomShape2d.cxx b/svx/source/customshapes/EnhancedCustomShape2d.cxx
index a23d95386ce3..cb226c3c9333 100644
--- a/svx/source/customshapes/EnhancedCustomShape2d.cxx
+++ b/svx/source/customshapes/EnhancedCustomShape2d.cxx
@@ -2205,7 +2205,7 @@ void EnhancedCustomShape2d::CreateSubPath(
                             // MS shapes and independent of the meaning of commands U and T in ODF specification.
 
                             // The WordArt shape 'RingOutside' has already angles in degree, all other need
-                            // convertion from fixed-point number.
+                            // conversion from fixed-point number.
                             double fSwingAngle = fEndAngle;
                             if (sShpType != "mso-spt143")
                             {
@@ -2268,7 +2268,7 @@ void EnhancedCustomShape2d::CreateSubPath(
                         {
                             // draw full ellipse
                             // Because createPolygonFromEllipseSegment cannot create full ellipse and
-                            // createPolygonFromEllipse has no variing starts, we use two half ellipses.
+                            // createPolygonFromEllipse has no varying starts, we use two half ellipses.
                             const double fS(lcl_getNormalizedCircleAngleRad(fWR, fHR, fStartAngle));
                             const double fH(lcl_getNormalizedCircleAngleRad(fWR, fHR, fStartAngle + 180.0));
                             const double fE(lcl_getNormalizedCircleAngleRad(fWR, fHR, fEndAngle));
diff --git a/svx/source/customshapes/EnhancedCustomShape3d.cxx b/svx/source/customshapes/EnhancedCustomShape3d.cxx
index fec339b5880c..2d53139baea4 100644
--- a/svx/source/customshapes/EnhancedCustomShape3d.cxx
+++ b/svx/source/customshapes/EnhancedCustomShape3d.cxx
@@ -498,7 +498,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject(
                         const XFillBitmapItem& rBmpItm = p3DObj->GetMergedItem(XATTR_FILLBITMAP);
                         aFillBmp = rBmpItm.GetGraphicObject().GetGraphic().GetBitmapEx();
 
-                        // #i122777# old adaption of FillStyle bitmap size to 5-times the original size; this is not needed
+                        // #i122777# old adaptation of FillStyle bitmap size to 5-times the original size; this is not needed
                         // anymore and was used in old times to male the fill look better when converting to 3D. Removed
                         // from regular 3D objects for some time, also needs to be removed from CustomShapes
 
diff --git a/svx/source/dialog/connctrl.cxx b/svx/source/dialog/connctrl.cxx
index e386c15dc2b0..22c7c831f6a8 100644
--- a/svx/source/dialog/connctrl.cxx
+++ b/svx/source/dialog/connctrl.cxx
@@ -211,7 +211,7 @@ void SvxXConnectionPreview::Paint(vcl::RenderContext& rRenderContext, const tool
         // objects without own model and without a page/view with the new
         // mechanism.
 
-        // New stuff: Use a ObjectContactOfObjListPainter.
+        // New stuff: Use an ObjectContactOfObjListPainter.
         sdr::contact::SdrObjectVector aObjectVector;
 
         for (size_t a = 0; a < pSdrPage->GetObjCount(); ++a)
diff --git a/svx/source/dialog/docrecovery.cxx b/svx/source/dialog/docrecovery.cxx
index b2731aa32afc..e5ad2666e609 100644
--- a/svx/source/dialog/docrecovery.cxx
+++ b/svx/source/dialog/docrecovery.cxx
@@ -366,7 +366,7 @@ void SAL_CALL RecoveryCore::statusChanged(const css::frame::FeatureStateEvent& a
 
     // b) normal notification about changed items
     //    FeatureDescriptor = "Update"
-    //    State             = Lits of information [seq< NamedValue >]
+    //    State             = List of information [seq< NamedValue >]
     if (aEvent.FeatureDescriptor != RECOVERY_OPERATIONSTATE_UPDATE)
         return;
 
diff --git a/svx/source/dialog/svxruler.cxx b/svx/source/dialog/svxruler.cxx
index 29cd1ee88901..d418afbe8e07 100644
--- a/svx/source/dialog/svxruler.cxx
+++ b/svx/source/dialog/svxruler.cxx
@@ -2881,7 +2881,7 @@ void SvxRuler::CalcMinMax()
                         nMaxLeft += nDragOffset;
 
                         // nMaxRight
-                        // linear / proprotional move
+                        // linear / proportional move
                         if((SvxRulerDragFlags::OBJECT_SIZE_PROPORTIONAL & nDragType) ||
                            (SvxRulerDragFlags::OBJECT_SIZE_LINEAR & nDragType) )
                         {
diff --git a/svx/source/engine3d/helperhittest3d.cxx b/svx/source/engine3d/helperhittest3d.cxx
index f5fc02d6456e..39b2ec2fe05a 100644
--- a/svx/source/engine3d/helperhittest3d.cxx
+++ b/svx/source/engine3d/helperhittest3d.cxx
@@ -67,7 +67,7 @@ static void getAllHit3DObjectWithRelativePoint(
 
     if(!rFront.equal(rBack))
     {
-        // rObject is a E3dCompoundObject, so it cannot be a scene (which is a E3dObject)
+        // rObject is an E3dCompoundObject, so it cannot be a scene (which is an E3dObject)
         const sdr::contact::ViewContactOfE3d& rVCObject = static_cast< sdr::contact::ViewContactOfE3d& >(rObject.GetViewContact());
         const drawinglayer::primitive3d::Primitive3DContainer aPrimitives(rVCObject.getViewIndependentPrimitive3DContainer());
 
@@ -110,7 +110,7 @@ E3dScene* fillViewInformation3DForCompoundObject(drawinglayer::geometry::ViewInf
 
         if(pParentParentScene)
         {
-            // pParentScene is a in-between scene
+            // pParentScene is an in-between scene
             aInBetweenSceneMatrix = pParentScene->GetTransform() * aInBetweenSceneMatrix;
         }
         else
diff --git a/svx/source/engine3d/helperminimaldepth3d.cxx b/svx/source/engine3d/helperminimaldepth3d.cxx
index 725dffa0c4d3..bceb7df00f6b 100644
--- a/svx/source/engine3d/helperminimaldepth3d.cxx
+++ b/svx/source/engine3d/helperminimaldepth3d.cxx
@@ -147,7 +147,7 @@ namespace drawinglayer
 
 double getMinimalDepthInViewCoordinates(const E3dCompoundObject& rObject)
 {
-    // this is a E3dCompoundObject, so it cannot be a scene (which is a E3dObject).
+    // this is an E3dCompoundObject, so it cannot be a scene (which is an E3dObject).
     // Get primitive sequence using VC
     const sdr::contact::ViewContactOfE3d& rVCObject = static_cast< sdr::contact::ViewContactOfE3d& >(rObject.GetViewContact());
     const drawinglayer::primitive3d::Primitive3DContainer aPrimitives = rVCObject.getViewIndependentPrimitive3DContainer();
@@ -168,7 +168,7 @@ double getMinimalDepthInViewCoordinates(const E3dCompoundObject& rObject)
             // and the object's transform is part of aPrimitives (and taken into account when decomposing
             // to PolygonHairlinePrimitive3D and PolyPolygonMaterialPrimitive3D). The missing part may be
             // some Scene SdrObjects lying in-between which may need to be added. This is e.g. used in chart,
-            // and generally allowed in 3d scenes an their 3d object hierarchy
+            // and generally allowed in 3d scenes and their 3d object hierarchy
             basegfx::B3DHomMatrix aInBetweenSceneMatrix;
             E3dScene* pParentScene(rObject.getParentE3dSceneFromE3dObject());
 
diff --git a/svx/source/engine3d/view3d.cxx b/svx/source/engine3d/view3d.cxx
index c18557d71f33..b6d170554f64 100644
--- a/svx/source/engine3d/view3d.cxx
+++ b/svx/source/engine3d/view3d.cxx
@@ -531,7 +531,7 @@ bool E3dView::ImpCloneAll3DObjectsToDestScene(E3dScene const * pSrcScene, E3dSce
                     basegfx::B3DRange aObjectRange(pNewCompoundObj->GetBoundVolume());
                     aObjectRange.transform(aObjectToWorldTrans);
 
-                    // get scale adaption
+                    // get scale adaptation
                     const basegfx::B3DVector aSceneScale(aSceneRange.getRange());
                     const basegfx::B3DVector aObjectScale(aObjectRange.getRange());
                     double fScale(1.0);
@@ -561,7 +561,7 @@ bool E3dView::ImpCloneAll3DObjectsToDestScene(E3dScene const * pSrcScene, E3dSce
                         fScale *= fFactor;
                     }
 
-                    // get translation adaption
+                    // get translation adaptation
                     const basegfx::B3DPoint aSceneCenter(aSceneRange.getCenter());
                     const basegfx::B3DPoint aObjectCenter(aObjectRange.getCenter());
 
diff --git a/svx/source/fmcomp/fmgridcl.cxx b/svx/source/fmcomp/fmgridcl.cxx
index 8605f053e07c..6bdc11d34938 100644
--- a/svx/source/fmcomp/fmgridcl.cxx
+++ b/svx/source/fmcomp/fmgridcl.cxx
@@ -684,7 +684,7 @@ void FmGridHeader::PreExecuteColumnContextMenu(sal_uInt16 nColId, PopupMenu& rMe
         sal_Int32 nColType = xServiceQuestion.is() ? getColumnTypeByModelName(xServiceQuestion->getServiceName()) : 0;
         if (nColType == TYPE_TEXTFIELD)
         {   // edit fields and formatted fields have the same service name, thus getColumnTypeByModelName returns TYPE_TEXTFIELD
-            // in both cases. And as columns don't have an css::lang::XServiceInfo interface, we have to distinguish both
+            // in both cases. And as columns don't have a css::lang::XServiceInfo interface, we have to distinguish both
             // types via the existence of special properties
             if (xPropSet.is())
             {
diff --git a/svx/source/fmcomp/fmgridif.cxx b/svx/source/fmcomp/fmgridif.cxx
index 5a18461de6a2..fb89600530f8 100644
--- a/svx/source/fmcomp/fmgridif.cxx
+++ b/svx/source/fmcomp/fmgridif.cxx
@@ -540,7 +540,7 @@ void SAL_CALL FmXGridControl::createPeer(const Reference< css::awt::XToolkit >&
             // forward the design mode
             bool bForceAlivePeer = m_bInDraw && !maComponentInfos.bVisible;
             // (we force an alive-mode peer if we're in "draw", cause in this case the peer will be used for drawing in
-            // foreign devices. We ensure this with the visibility check as an living peer is assumed to be noncritical
+            // foreign devices. We ensure this with the visibility check as a living peer is assumed to be noncritical
             // only if invisible)
             Any aOldCursorBookmark;
             if (!mbDesignMode || bForceAlivePeer)
@@ -1468,8 +1468,8 @@ sal_Bool FmXGridPeer::commit()
 void FmXGridPeer::cursorMoved(const EventObject& _rEvent)
 {
     VclPtr< FmGridControl > pGrid = GetAs< FmGridControl >();
-    // we are not interested in move to insert row only in the resetted event
-    // which is fired after positioning an the insert row
+    // we are not interested in moving to insert row only in the reset event
+    // which is fired after positioning and the insert row
     if (pGrid && pGrid->IsOpen() && !::comphelper::getBOOL(Reference< XPropertySet > (_rEvent.Source, UNO_QUERY_THROW)->getPropertyValue(FM_PROP_ISNEW)))
         pGrid->positioned();
 }
@@ -2622,7 +2622,7 @@ Sequence< css::util::URL>& FmXGridPeer::getSupportedURLs()
         for ( sal_Int32 i = 0; i < tmp.getLength(); ++i, ++pSupported)
             pSupported->Complete = OUString::createFromAscii(sSupported[i]);
 
-        // let an css::util::URL-transformer normalize the URLs
+        // let a css::util::URL-transformer normalize the URLs
         Reference< css::util::XURLTransformer >  xTransformer(
             util::URLTransformer::create(::comphelper::getProcessComponentContext()) );
         for (css::util::URL & rURL : tmp)
diff --git a/svx/source/fmcomp/gridctrl.cxx b/svx/source/fmcomp/gridctrl.cxx
index 202efac174f4..d30818511578 100644
--- a/svx/source/fmcomp/gridctrl.cxx
+++ b/svx/source/fmcomp/gridctrl.cxx
@@ -1224,7 +1224,7 @@ namespace
             _rMode &= ~BrowserMode( BrowserMode::NO_HSCROLL | BrowserMode::NO_VSCROLL );
         }
 
-        // note: if we have a navigation bar, we always have a AUTO_HSCROLL. In particular,
+        // note: if we have a navigation bar, we always have an AUTO_HSCROLL. In particular,
         // _bHideScrollbars is ignored then
         if ( _bNavigationBar )
         {
@@ -1418,7 +1418,7 @@ void DbGridControl::setDataSource(const Reference< XRowSet >& _xCursor, DbGridCo
 
     // is the new cursor valid ?
     // the cursor is only valid if it contains some columns
-    // if there is no cursor or the cursor is not valid we have to clean up an leave
+    // if there is no cursor or the cursor is not valid we have to clean up and leave
     if (!_xCursor.is() || !Reference< XColumnsSupplier > (_xCursor, UNO_QUERY_THROW)->getColumns()->hasElements())
     {
         RemoveRows();
@@ -1482,7 +1482,7 @@ void DbGridControl::setDataSource(const Reference< XRowSet >& _xCursor, DbGridCo
     // (Normally one class would be sufficient : the multiplexer which could forward the property change to us.
     // But for that we would have been derived from ::comphelper::OPropertyChangeListener, which isn't exported.
     // So we introduce a second class, which is a ::comphelper::OPropertyChangeListener (in the implementation file we know this class)
-    // and forwards the property changes to a our special method "DataSourcePropertyChanged".)
+    // and forwards the property changes to our special method "DataSourcePropertyChanged".)
     if (m_pDataCursor)
     {
         m_pDataSourcePropListener = new FmXGridSourcePropListener(this);
@@ -2287,7 +2287,7 @@ sal_Int32 DbGridControl::AlignSeekCursor()
                     // somewhere) -> retry
                     m_pSeekCursor->moveToBookmark(m_pDataCursor->getBookmark());
                     // Now there is still the chance of a failure but it is less likely.
-                    // The alternative would be an loop until everything is fine - no good solution...
+                    // The alternative would be a loop until everything is fine - no good solution...
                 m_nSeekPos = m_pSeekCursor->getRow() - 1;
             }
         }
@@ -2714,7 +2714,7 @@ void DbGridControl::DataSourcePropertyChanged(const PropertyChangeEvent& evt)
             sal_Int32 nRecordCount = 0;
             xSource->getPropertyValue(FM_PROP_ROWCOUNT) >>= nRecordCount;
             if (::comphelper::getBOOL(evt.NewValue))
-            {   // modified state changed from sal_False to sal_True and we're on a insert row
+            {   // modified state changed from sal_False to sal_True and we're on an insert row
                 // -> we've to add a new grid row
                 if ((nRecordCount == GetRowCount() - 1)  && m_xCurrentRow->IsNew())
                 {
@@ -2724,7 +2724,7 @@ void DbGridControl::DataSourcePropertyChanged(const PropertyChangeEvent& evt)
                 }
             }
             else
-            {   // modified state changed from sal_True to sal_False and we're on a insert row
+            {   // modified state changed from sal_True to sal_False and we're on an insert row
                 // we have two "new row"s at the moment : the one we're editing currently (where the current
                 // column is the only dirty element) and a "new new" row which is completely clean. As the first
                 // one is about to be cleaned, too, the second one is obsolete now.
@@ -3007,7 +3007,7 @@ void DbGridControl::Undo()
         // remove the row
         if (m_nCurrentPos == GetRowCount() - 2)
         {   // maybe we already removed it (in resetCurrentRow, called if the above moveToInsertRow
-            // caused our data source form to be reset - which should be the usual case ....)
+            // caused our data source form to be reset - which should be the usual case...)
             RowRemoved(GetRowCount() - 1);
             m_aBar->InvalidateAll(m_nCurrentPos);
         }
diff --git a/svx/source/form/filtnav.cxx b/svx/source/form/filtnav.cxx
index 27d7c2d61a37..e68594ffd4af 100644
--- a/svx/source/form/filtnav.cxx
+++ b/svx/source/form/filtnav.cxx
@@ -1518,7 +1518,7 @@ void FmFilterNavigator::StartDrag( sal_Int8 /*_nAction*/, const Point& /*_rPosPi
 {
     EndSelection();
 
-    // be sure that the data is only used within a only one form!
+    // be sure that the data is only used within an only one form!
     m_aControlExchange.prepareDrag();
 
     ::std::vector<FmFilterItem*> aItemList;
diff --git a/svx/source/form/fmscriptingenv.cxx b/svx/source/form/fmscriptingenv.cxx
index bddfc8827b6f..878639570bd9 100644
--- a/svx/source/form/fmscriptingenv.cxx
+++ b/svx/source/form/fmscriptingenv.cxx
@@ -183,7 +183,7 @@ namespace svxform
     bool FormScriptListener::impl_allowAsynchronousCall_nothrow( const OUString& _rListenerType, const OUString& _rMethodName )
     {
         // This used to be implemented as:
-        // is (_rListenerType + "::" + _rMethodName) a oneway function?
+        // is (_rListenerType + "::" + _rMethodName) an oneway function?
         // since we got rid of the notion of oneway, this is the list
         // of oneway methods, autogenerated by postprocessing of
         // commitdiff 90eac3e69749a9227c4b6902b1f3cef1e338c6d1
diff --git a/svx/source/form/fmshell.cxx b/svx/source/form/fmshell.cxx
index c99c84569cbf..eb4d4c4c56f5 100644
--- a/svx/source/form/fmshell.cxx
+++ b/svx/source/form/fmshell.cxx
@@ -759,7 +759,7 @@ void FmFormShell::Execute(SfxRequest &rReq)
                 Reference<runtime::XFormController> const xController(GetImpl()->getActiveController_Lock());
 
                 if  (   GetViewShell()->GetViewFrame()->HasChildWindow( SID_FM_FILTER_NAVIGATOR )
-                        // closing the window was denied, for instance because of a invalid criterion
+                        // closing the window was denied, for instance because of an invalid criterion
 
                     ||  (   xController.is()
                         &&  !GetImpl()->getActiveControllerFeatures_Lock()->commitCurrentControl()
diff --git a/svx/source/form/fmshimp.cxx b/svx/source/form/fmshimp.cxx
index 0c896ef0436b..553c03cbeb18 100644
--- a/svx/source/form/fmshimp.cxx
+++ b/svx/source/form/fmshimp.cxx
@@ -2897,7 +2897,7 @@ void FmXFormShell::impl_collectFormSearchContexts_nothrow_Lock( const Reference<
                 aNextLevelPrefix.append( '/' );
             aNextLevelPrefix.append( sCurrentFormName );
 
-            // remember both the form and it's "display name"
+            // remember both the form and its "display name"
             _out_rForms.push_back( xCurrentAsForm );
             _out_rNames.push_back( sCompleteCurrentName.makeStringAndClear() );
 
@@ -3756,7 +3756,7 @@ namespace
             if ( isEmbeddedInDatabase( _rxLoadable.get(), xConn ) )
                 return true;
 
-            // is there already a active connection
+            // is there already an active connection
             xSet->getPropertyValue(FM_PROP_ACTIVE_CONNECTION) >>= xConn;
             if ( xConn.is() )
                 return true;


More information about the Libreoffice-commits mailing list
diff --git a/svx/source/accessibility/ChildrenManagerImpl.hxx b/svx/source/accessibility/ChildrenManagerImpl.hxx
index 5998486e7cf9..f0abbfdff22c 100644
--- a/svx/source/accessibility/ChildrenManagerImpl.hxx
+++ b/svx/source/accessibility/ChildrenManagerImpl.hxx
@@ -91,7 +91,7 @@ public:
         @param rxShapeList
             List of UNO shapes to manage.
         @param rShapeTreeInfo
-            Bundel of information passed down the shape tree.
+            Bundle of information passed down the shape tree.
         @param rContext
             An accessible context object that is called for fireing events
             for new and deleted children, i.e. that holds a list of
@@ -182,7 +182,7 @@ public:
     void Update (bool bCreateNewObjectsOnDemand);
 
     /** Set the list of UNO shapes to the given list.  This removes the old
-        list and does not add to it.  The list of accessible shapes that is
+        list and does not add to it. The list of accessible shapes that is
         build up by calls to <member>AddAccessibleShape</member> is not
         modified.  Neither is the list of visible children.  Accessible
         objects are created on demand.
@@ -191,7 +191,7 @@ public:
     */
     void SetShapeList (const css::uno::Reference<css::drawing::XShapes>& xShapeList);
 
-    /** Add a accessible shape.  This does not modify the list of UNO shapes
+    /** Add an accessible shape.  This does not modify the list of UNO shapes
         or the list of visible shapes.  Accessible shapes are, at the
         moment, not tested against the visible area but are always appended
         to the list of visible children.
@@ -320,7 +320,7 @@ private:
     */
     css::uno::Reference<css::accessibility::XAccessible> mxParent;
 
     /** Bundel of information passed down the shape tree.
     */
     AccessibleShapeTreeInfo maShapeTreeInfo;
 
@@ -320,7 +320,7 @@ private:
     css::uno::Reference<css::accessibility::XAccessible> mxParent;
 
-    /** Bundel of information passed down the shape tree.
+    /** Bundle of information passed down the shape tree.
     */
     AccessibleShapeTreeInfo maShapeTreeInfo;